@@ -69,7 +69,7 @@ static char print_usage[]={
 "  where:\n"
 "    repeatinterval-ms: timing, in milliseconds of sending arp packets\n"
 "      For each ARP announcement requested, a pair of ARP packets is sent,\n"
-"      an ARP request, and an ARP reply. This is becuse some systems\n"
+"      an ARP request, and an ARP reply. This is because some systems\n"
 "      ignore one or the other, and this combination gives the greatest\n"
 "      chance of success.\n"
 "\n"
@@ -81,7 +81,7 @@ static char print_usage[]={
 "\n"
 "    pidfile: pid file to use\n"
 "\n"
-"    device: netowrk interace to use\n"
+"    device: network interface to use\n"
 "\n"
 "    src_ip_addr: source ip address\n"
 "\n"
@@ -720,7 +720,7 @@ write_pid_file(const char *pidfilename)
 		}
 
 		if (kill(pid, SIGKILL) < 0 && errno != ESRCH) {
-			cl_log(LOG_INFO, "Error killing old proccess [%lu] "
+			cl_log(LOG_INFO, "Error killing old process [%lu] "
 	 				"from pid-file [%s]: %s", pid,
 					pidfilename, strerror(errno));
 			return -1;
